# Analysis of bobcat 2011 data using transects in 200-m sections as proximity detectors 
#   Scats are linked to nearest 200-m section
#   
#
# Written by Duane R. Diefenbach, October 2014

library(secr)
library(abind)
library(maptools)

# Shapefile of island boundary of upland habitats
boundary <- readShapeSpatial("CamdenCoUplandBoundary")


bobcat <- read.capthist("caploc.txt","traploc.txt", detector="proximity")
summary(bobcat)


# Plot island and locations of bobcat scat
plot(boundary)
plot(bobcat,add=TRUE)

# Run spatial capture-recapture model
bobcat.fit <- secr.fit(capthist=bobcat, buffer = 3 * RPSV(bobcat), method="Nelder-Mead")
bobcat.fit
region.N(bobcat.fit, region = boundary)

# Re-run model fitting to get convergence of parameter estimates
 bobcatvar.fit <- secr.fit(bobcat, start=bobcat.fit, buffer=3*RPSV(bobcat), details = list(centred=TRUE),
                 method="none")
 bobcatvar.fit
 region.N(bobcatvar.fit, region = boundary, RN.method="MSPE")